@@ -6,13 +6,13 @@
 ##' less than radius.
 ##' The search can be done for spatial or spatio-temporal clusters.
 ##' The significance of the clusters is obtained with a Monte Carlo procedure
-##' or based on the chi-square distribution (\link{glm}, \link{glmer} or zeroinfl models)
+##' or based on the chi-square distribution (\link{glm}, \link[lme4]{glmer} or zeroinfl models)
 ##' or DIC (\code{inla} models).
 ##'
 ##' @param stfdf object containing the data.
-##' If data is spatial, stfdf is a \link{SpatialPolygonsDataFrame} object from sp.
-##' If data is spatio-temporal, stfdf is a \link{STFDF} object from spacetime.
-##' The data contain a \link{SpatialPolygons} object with the coordinates,
+##' If data is spatial, stfdf is a \link[sp]{SpatialPolygonsDataFrame} object from sp.
+##' If data is spatio-temporal, stfdf is a \link[spacetime]{STFDF} object from spacetime.
+##' The data contain a \link[sp]{SpatialPolygons} object with the coordinates,
 ##' and if applicable, a time object holding time information,
 ##' an endTime vector of class \link{POSIXct} holding end points of time intervals.
 ##' It also contain a data.frame with the Observed, Expected and potential covariates
@@ -35,8 +35,8 @@
 ##' Monte Carlo procedure, R represents the number replicates under the null hypothesis.
 ##' @param model0 Initial model (including covariates).
 ##' @param ClusterSizeContribution Indicates the variable to be used as the population at risk in the cluster. This is the variable name to be used by 'fractpop' when checking the fraction of the population inside the cluster. The default column name is 'Population'.
-##' This can be "glm" for generalized linear models (\link{glm} {stats}),
-##' "glmer" for generalized linear mixed model (\link{glmer} {lme4}),
+##' This can be "glm" for generalized linear models (\link[stats]{glm}),
+##' "glmer" for generalized linear mixed model (\link[lme4]{glmer}),
 ##' "zeroinfl" for zero-inflated models (zeroinfl), or
 ##' "inla" for generalized linear, generalized linear mixed or zero-inflated models fitted with \code{inla}.
 ##'
@@ -55,7 +55,7 @@
 ##'
 ##' Bilancia M, Demarinis G (2014) Bayesian scanning of spatial disease rates
 ##' with the Integrated Nested Laplace Approximation (INLA). Statistical
-##' Methods & Applications 23(1): 71 - 94. \url{http://dx.doi.org/10.1007/s10260-013-0241-8}
+##' Methods & Applications 23(1): 71 - 94. \doi{10.1007/s10260-013-0241-8}
 ##'
 ##' Jung I (2009) A generalized linear models approach to spatial scan 
 ##' statistics for covariate adjustment. Statistics in Medicine 28(7): 1131 - 1143.
@@ -118,12 +118,12 @@ DetectClustersModel <- function(stfdf, thegrid = NULL, radius = Inf,
   
   
   #############################
-  # If data is spatial, stfdf is a \link{SpatialPolygonsDataFrame} object. We need to convert it to \link{STFDF}. We add date as.Date("1970-01-01").
-  # If data is spatio-temporal, stfdf is a \link{STFDF} object.
+  # If data is spatial, stfdf is a \link[sp]{SpatialPolygonsDataFrame} object. We need to convert it to \link[spacetime]{STFDF}. We add date as.Date("1970-01-01").
+  # If data is spatio-temporal, stfdf is a \link[spacetime]{STFDF} object.
 
   #Spatial object?
   is.sp <- FALSE
-  if(class(stfdf) == "SpatialPolygonsDataFrame"){
+  if(inherits(stfdf, "SpatialPolygonsDataFrame")){
     is.sp <- TRUE
     stfdf <- STFDF(as(stfdf, "SpatialPolygons"), xts(1, as.Date("1970-01-01")),
                    stfdf@data, endTime = as.POSIXct(strptime(c("1970-01-01"), "%Y-%m-%d"), tz = "GMT"))
